@@ -18,10 +18,10 @@ var searchData=
   ['max_5falign_15',['max_align',['../structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7',1,'spa_buffer_alloc_info']]],
   ['max_5fframerate_16',['max_framerate',['../structspa__video__info__h264.html#af680ca708a6fac71a3236cb73e1e1fc1',1,'spa_video_info_h264::max_framerate'],['../structspa__video__info__mjpg.html#a79a7bc729e3b98faa7285d6475b9867b',1,'spa_video_info_mjpg::max_framerate'],['../structspa__video__info__raw.html#af59a82989f29004917bb4f62b003addb',1,'spa_video_info_raw::max_framerate']]],
   ['max_5finput_5fports_17',['max_input_ports',['../structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e',1,'pw_node_info::max_input_ports'],['../structspa__node__info.html#a9f05f762157f2ae9db446937f19da173',1,'spa_node_info::max_input_ports']]],
-  ['max_5fns_18',['max_ns',['../structspa__latency__info.html#ae4923a45e4de7d99b8aa658c4e59235e',1,'spa_latency_info']]],
+  ['max_5fns_18',['max_ns',['../structspa__latency__info.html#ad483ad02d7fa54b3069970ab7a636fd5',1,'spa_latency_info']]],
   ['max_5foutput_5fports_19',['max_output_ports',['../structpw__node__info.html#ac312e1844784e77e412f6bb341814372',1,'pw_node_info::max_output_ports'],['../structspa__node__info.html#a5c181a5c275e9a0c9ec82156a38f10a5',1,'spa_node_info::max_output_ports']]],
   ['max_5fquantum_20',['max_quantum',['../structspa__latency__info.html#aab5617769d3799f99a80747917268db8',1,'spa_latency_info']]],
-  ['max_5frate_21',['max_rate',['../structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec',1,'spa_latency_info']]],
+  ['max_5frate_21',['max_rate',['../structspa__latency__info.html#a9241f63614bcb363ad375b6fb07d251e',1,'spa_latency_info']]],
   ['max_5fsize_22',['max_size',['../structspa__io__range.html#adac0f561e72d269206216a3327720ff7',1,'spa_io_range']]],
   ['max_5fvalues_23',['max_values',['../structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046',1,'pw_stream_control']]],
   ['maxsize_24',['maxsize',['../structspa__data.html#ae942ee4f53c1ae2b708fdea5aa334406',1,'spa_data::maxsize'],['../structspa__strbuf.html#ac82fdbc33669185a77140a3faf908a0c',1,'spa_strbuf::maxsize']]],
@@ -33,7 +33,7 @@ var searchData=
   ['mem_5fid_30',['mem_id',['../structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392',1,'pw_client_node_buffer']]],
   ['mem_5fsize_31',['mem_size',['../structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6',1,'spa_buffer_alloc_info']]],
   ['memory_20blocks_32',['Memory Blocks',['../group__pw__memblock.html',1,'']]],
-  ['message_33',['message',['../structspa__result__node__error.html#a396020ed7279b7f3293cc2c2eec47485',1,'spa_result_node_error']]],
+  ['message_33',['message',['../structspa__result__node__error.html#a396020ed7279b7f3293cc2c2eec47485',1,'spa_result_node_error::message'],['../group__pw__core.html#gabdc784a574a73c467696f4032d108429',1,'message:&#160;core.h']]],
   ['message_20header_34',['Message header',['../page_native_protocol.html#native-protocol-message-header',1,'']]],
   ['meta_2eh_35',['meta.h',['../meta_8h.html',1,'']]],
   ['meta_5fsize_36',['meta_size',['../structspa__buffer__alloc__info.html#a63296028aeb53c2e98501c78f1d53617',1,'spa_buffer_alloc_info']]],
@@ -46,9 +46,9 @@ var searchData=
   ['midi_20support_43',['MIDI Support',['../page_midi.html',1,'page_internals']]],
   ['mididump_44',['pw-mididump',['../page_man_pw-mididump_1.html',1,'page_programs']]],
   ['min_45',['min',['../structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62',1,'pw_stream_control::min'],['../structspa__io__latency.html#a017f13089f0f6847cd70e62d725bd99c',1,'spa_io_latency::min']]],
-  ['min_5fns_46',['min_ns',['../structspa__latency__info.html#ac9e3498891f63e0c2f6e6df171febb5b',1,'spa_latency_info']]],
+  ['min_5fns_46',['min_ns',['../structspa__latency__info.html#a203b83cfc08a9e968691577fd1dce326',1,'spa_latency_info']]],
   ['min_5fquantum_47',['min_quantum',['../structspa__latency__info.html#aadaa9a123ffe5f4a050945e210cc5725',1,'spa_latency_info']]],
-  ['min_5frate_48',['min_rate',['../structspa__latency__info.html#a114447a982c76675818ca5fff6e5b101',1,'spa_latency_info']]],
+  ['min_5frate_48',['min_rate',['../structspa__latency__info.html#a04589efd15d0106f14fc7cd93d938145',1,'spa_latency_info']]],
   ['min_5fsize_49',['min_size',['../structspa__io__range.html#af3d7c25e34fd60458e8ca8cfa1067c92',1,'spa_io_range']]],
   ['minutes_50',['minutes',['../structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db',1,'spa_io_segment_video']]],
   ['miscellaneous_51',['Miscellaneous',['../group__spa__utils__defs.html',1,'']]],
